pub struct GraphicsSettingsController { /* private fields */ }Trait Implementations
Sourceimpl Module for GraphicsSettingsController
impl Module for GraphicsSettingsController
Sourcetype Config = ()
type Config = ()
Some initial data that configures the module. Provided by the User when adding a module to an app.
Sourcetype Dependencies = DefaultDependencies
type Dependencies = DefaultDependencies
Other modules that are expected to be part of the app. Provided automatically during app setup, where the program
resolves which dependencies each module has.
Sourcefn intialize(handle: Handle<Self>) -> Result<()>
fn intialize(handle: Handle<Self>) -> Result<()>
Is run once, after all modules have been initialized.
This function is optional, it is given a handle to the module itself.
other modules can be accessed if you cache the handles to them in the ) with a general Renderer module,
if a
new() function.
E.g. the LineRenderer could register its own handle (HandleHandle<Renderer> was part of the Self::Dependencies and cached in the new function.
E.g. LineRenderer could have a field renderer: Handle<Renderer> that is populated in new.Auto Trait Implementations
impl Freeze for GraphicsSettingsController
impl !RefUnwindSafe for GraphicsSettingsController
impl !Send for GraphicsSettingsController
impl !Sync for GraphicsSettingsController
impl Unpin for GraphicsSettingsController
impl !UnwindSafe for GraphicsSettingsController