pub struct Timing(/* private fields */);Expand description
Timing can be thought of as the inverse of Priority. A high timing value means, a function will be executed later in a schedule.
Implementations